from qda_modelos.chlorophylla import (
    gordon_morel_1983,
    gons_1999,
    dallolmo_gitelson_rundquist_2003,
    gitelson_et_al_2007,
    le_et_al_2009,
    mishra_mishra_2012,
    rodrigues_et_al_2016,
    chavula_et_al_2009,
    allan_hicks_brabyn_2006,
    gower_et_al_2005,
)

from qda_modelos.cyanobacteria import (
    simis_et_al_2005,
    dash_et_al_2011,
    wozniak_et_al_2016,
)

from qda_modelos.macrophytes import (
    tucker_1979,
    huete_et_al_1997,
    villa_et_al_2013,
    villa_et_al_2014,
)

from qda_modelos.total_suspended_solids_turbidity import (
    doxaran_et_al_2003,
    doxaran_et_al_2009,
    miller_mckee_2004,
    liu_et_al_2006,
    tarrant_et_al_2010,
    zhang_et_al_2010,
    tang_et_al_2010,
)

from qda_modelos.water_transparency import (
    giardino_et_al_2001,
    harma_et_al_2001,
    guimaraes_et_al_2016,
)

from qda_modelos.trophic_state_index import (
    lamparelli_2004,
)

from qda_modelos.reservoir_water_quality_index import (
    instituto_ambiental_parana_2004,
)
